@@ -45,7 +45,6 @@ from lino.core import fields
 #~ from lino.core.perms import UserLevels
 #~ from lino.core import perms 
 
-
 PLAIN_PAGE_LENGTH = 15
 
 
@@ -126,6 +125,9 @@ def add_requirements(obj,**kw):
 
 
 
+
+
+
 def register_params(cls):
     #~ if cls.__class__.__name__ == 'Merge':
         #~ print("20130121 register_params",cls.parameters)
@@ -235,6 +237,10 @@ class InstanceAction(object):
         #~ print "Bar"
         #~ self.action = action
         self.bound_action = actor.get_action_by_name(action.action_name)
+        if self.bound_action is None:
+            raise Exception("%s has not action %r" % (actor,action))
+            # happened 20131020 from beid.eid_info() : if use_eid_jslib was False
+            # then Action.attach_to_actor returned False
         self.instance = instance
         self.owner = owner
         
@@ -462,7 +468,10 @@ class Action(Parametrizable,Permittable):
     """
     
     select_rows = True
+    #~ select_rows = False
     """
+    TODO: rename this to "single_row".
+    True if this action should be called on a single row (ignoring multiple row selection)..
     Set this to False if this action is a list action, not a row action.
     """
     
@@ -633,6 +642,13 @@ class Action(Parametrizable,Permittable):
         setup_params_choosers(self.__class__)
         
     def attach_to_actor(self,actor,name):
+        """
+        Called once per Actor per Action on startup before a BoundAction 
+        instance is being created.
+        If this returns False, then the action won't be attached to the given actor.
+        """
+        if not actor.editable and not self.readonly:
+            return False
         #~ if self.name is not None:
             #~ raise Exception("%s tried to attach named action %s" % (actor,self))
         #~ if actor == self.defining_actor:
@@ -681,6 +697,8 @@ class Action(Parametrizable,Permittable):
         
     def get_view_permission(self,profile):
         """
+        Return True if this action is visible for users of given profile.
+        
         Overridden e.g. by :class:`lino.mixins.beid.BeIdReadCardAction`
         to make it available only when :attr:`lino.Lino.use_eid_jslib` is True.
         """
@@ -871,7 +889,7 @@ class ShowDetailAction(Action):
         
         navigator = None
         if pk and pk != '-99999' and pk != '-99998':
-            elem = rpt.get_row_by_pk(pk)
+            elem = ar.get_row_by_pk(pk)
             if elem is None:
                 raise http.Http404("%s has no row with primary key %r" % (rpt,pk))
                 #~ raise Exception("20120327 %s.get_row_by_pk(%r)" % (rpt,pk))
@@ -989,7 +1007,10 @@ class ShowEmptyTable(ShowDetailAction):
     icon_name = None
     
     def is_callable_from(self,caller):
-        return True
+        return isinstance(caller,GridEdit)
+        
+    #~ def is_callable_from(self,caller):
+        #~ return True
     
     def attach_to_actor(self,actor,name):
         self.label = actor.label
