@@ -27,7 +27,10 @@ CHOICES_VALUE_FIELD = 'value'
 CHOICES_HIDDEN_SUFFIX = "Hidden"
 
 
+URL_PARAM_PROJECT = 'prj'
 URL_PARAM_TEAM_VIEW = 'tv'
+URL_PARAM_END_DATE = 'ed'
+URL_PARAM_START_DATE = 'sd'
 
 URL_PARAM_PARAM_VALUES = 'pv'
 URL_PARAM_FIELD_VALUES = 'fv'
@@ -87,6 +90,8 @@ URL_PARAM_COLUMNS = 'ci'
 URL_PARAM_SHOW_PARAMS_PANEL = 'sp'
 #~ TEST = 'name'
 
+URL_PARAM_SELECTED = 'sr'
+
 URL_PARAMS = [
   'URL_PARAM_ACTION_NAME',
   'URL_PARAM_FORMAT',
@@ -106,11 +111,11 @@ URL_PARAMS = [
   'URL_PARAM_SUBST_USER',
   'URL_PARAM_USER_LANGUAGE',
   'URL_PARAM_ACTION_STEP',
+  'URL_PARAM_SELECTED',
   #~ 'TEST',
 ]
 
 #~ URL_PARAM_CHOICES_PK = "ck"
-#~ URL_PARAM_SELECTED = 'selected'
 
 #~ FMT_RUN = 'act'
 #~ FMT_JSON = 'json'
