@@ -535,7 +535,7 @@ class Table(AbstractTable):
         return self.model._meta.pk
         
     @classmethod
-    def get_row_by_pk(self,pk):
+    def get_row_by_pk(self,ar,pk):
         try:
             return self.model.objects.get(pk=pk)
         except ValueError:
@@ -880,6 +880,10 @@ class Table(AbstractTable):
 
     @classmethod
     def create_instance(self,ar,**kw):
+        """
+        Create a model instance using the specified keyword args,
+        calling also :meth:`lino.core.model.Model.on_create`.
+        """
         #~ print 20120630, "Actor.create_instance", kw
         instance = self.model(**kw)
         instance.on_create(ar)
