@@ -74,7 +74,7 @@ class MergePlan(object):
     def logmsg(self):
         #~ self.analyze()
         lst = []
-        lst.append("Merge %s into %s") % (self.obj,self.merge_to)
+        lst.append(_("Merge %(origin)s into %(target)s") % dict(origin=self.obj,target=self.merge_to))
         def add(name):
             for f,qs in getattr(self,name):
                 if qs.count() > 0:
@@ -145,7 +145,7 @@ class MergePlan(object):
         return msg
 
     
-class MergeAction(actions.RowAction):
+class MergeAction(actions.Action):
     help_text = _("Merge this object into another object of same class.")
     label = _("Merge")
     sort_index = 31
@@ -226,8 +226,8 @@ class MergeAction(actions.RowAction):
         #~ kw.update(merge_from=obj)
         #~ return kw
 
-    def run_from_ui(self,obj,ar,**kw):
-
+    def run_from_ui(self,ar,**kw):
+        obj = ar.selected_rows[0]
         mp = MergePlan(obj,ar.action_param_values.merge_to,ar.action_param_values)
         msg = mp.build_confirmation_message()
         def ok():
