@@ -84,6 +84,7 @@ class BaseRequest(object):
     :meth:`login <lino.site.Site.login>`.
     """
     renderer = None
+    selected_rows = []
     
     #~ def __init__(self,request=None,renderer=None,**kw):
     def __init__(self,request=None,**kw):
@@ -146,7 +147,8 @@ class BaseRequest(object):
         kw.update(current_project=rqdata.get(ext_requests.URL_PARAM_PROJECT,None))
         
         selected = rqdata.getlist(ext_requests.URL_PARAM_SELECTED)
-        kw.update(selected_rows = [self.actor.get_row_by_pk(pk) for pk in selected])
+        #~ kw.update(selected_rows = [self.actor.get_row_by_pk(pk) for pk in selected])
+        kw.update(selected_pks=selected)
         
         #~ if settings.SITE.user_model:
             #~ username = rqdata.get(ext_requests.URL_PARAM_SUBST_USER,None)
@@ -162,19 +164,26 @@ class BaseRequest(object):
             user=None,
             subst_user=None,
             current_project=None,
-            selected_rows=None,
+            #~ selected_rows=None,
+            selected_pks=None,
             requesting_panel=None,
             renderer=None):
         self.requesting_panel = requesting_panel
         self.user = user 
         self.current_project = current_project
-        self.selected_rows = selected_rows
+        #~ self.selected_rows = selected_rows
         if renderer is not None:
             self.renderer = renderer
         #~ if self.actor.parameters:
             #~ self.param_values = AttrDict(**param_values)
         self.subst_user = subst_user
         
+        if selected_pks is not None:
+            self.set_selected_pks(*selected_pks)
+        
+    def set_selected_pks(self,*selected_pks):
+        #~ print 20131003, selected_pks
+        self.selected_rows = [self.get_row_by_pk(pk) for pk in selected_pks]
         
     #~ def dialog(self,dlg):
         #~ # not finished
@@ -257,8 +266,8 @@ class BaseRequest(object):
         
     def spawn(self,spec,**kw):
         """
-        Create a new ActionRequest, taking an "action specificator" 
-        and using default values from this one.
+        Create a new ActionRequest using default values from this one 
+        and the action specified by `spec`.
         
         """
         if isinstance(spec,ActionRequest):
@@ -297,6 +306,36 @@ class BaseRequest(object):
         #~ set_language(*args)
         
     def show(self,spec,master_instance=None,column_names=None,language=None,**kw):
+        """
+        Show the table specified by `spec` according to the current 
+        renderer. 
+        If the table is a :term:`slave table`, then a `master_instance` 
+        must be specified as second argument.
+        
+        Optional keyword arguments are
+        
+        - `column_names` overrides default list of columns
+        - `language` overrides the default language used for headers 
+          and translatable data
+        
+        Usage in a tested doc::
+        
+          >>> ar = settings.SITE.login("robin")
+          >>> ar.show('users.UsersOverview')
+        
+        Usage in a Jinja template::
+        
+          {{ar.show('users.UsersOverview')}}
+        
+        Usage in an appy.pod template::
+        
+          do text from ar.show('users.UsersOverview')
+        
+        Note that this function 
+        either returns a string or prints to stdout and returns None,
+        depending on the current renderer.
+         
+        """
         # 20130905 added master_instance positional arg. but finally didn't use it.
         if master_instance is not None:
             kw.update(master_instance=master_instance)
@@ -305,8 +344,8 @@ class BaseRequest(object):
         if language:
             #~ spec.set_language(language)
             with translation.override(language):
-                return ar.renderer.show(ar,column_names=column_names)
-        return ar.renderer.show(ar,column_names=column_names)
+                return ar.renderer.show_request(ar,column_names=column_names)
+        return ar.renderer.show_request(ar,column_names=column_names)
         
     def summary_row(self,obj,**kw): return obj.summary_row(self,**kw)
     def instance_handler(self,*args,**kw): return self.renderer.instance_handler(self,*args,**kw)
@@ -486,6 +525,10 @@ class ActionRequest(BaseRequest):
             
         
     def create_instance(self,**kw):
+        """
+        Create a row (a model instance if this is a database table) 
+        using the specified keyword arguments.
+        """
         if self.create_kw:
             kw.update(self.create_kw)
         #logger.debug('%s.create_instance(%r)',self,kw)
@@ -558,6 +601,7 @@ class ActionRequest(BaseRequest):
     #~ def prompt(self,*args,**kw): return self.ui.prompt(self,*args,**kw)
     def summary_row(self,*args,**kw): return self.actor.summary_row(self,*args,**kw)
     def get_sum_text(self): return self.actor.get_sum_text(self)
+    def get_row_by_pk(self,pk): return self.actor.get_row_by_pk(self,pk)
     def as_html(self,*args,**kw): return self.bound_action.action.as_html(self,*args,**kw)
         
     def absolute_uri(self,*args,**kw):
@@ -572,4 +616,9 @@ class ActionRequest(BaseRequest):
         """
         return self.actor.to_rst(self,*args,**kw)
 
+    def run(self,*args,**kw):
+        """
+        Runs this action request.
+        """
+        return self.bound_action.action.run_from_code(self,*args,**kw)
 
