@@ -412,6 +412,14 @@ class ExtRenderer(HtmlRenderer):
         #~ url = self.request_handler(rr)
         #~ return self.href(url,text or cgi.escape(force_unicode(rr.label)))
         
+    def show_request(self,ar,**kw):
+        """
+        Returns a HTML element representing this request as a table.
+        Used by appy_pod rendered.
+        """
+        return ar.table2xhtml(**kw)
+        #~ return E.tostring(ar.table2xhtml())
+        
     def handler_item(self,mi,handler,help_text):
         #~ handler = "function(){%s}" % handler
         #~ d = dict(text=prepare_label(mi),handler=js_code(handler),tooltip="Foo")
@@ -1318,7 +1326,10 @@ tinymce.init({
             if not k in self.SUPPRESSED:
                 yield "  %s: %s," % (k,py2js(v))
         #~ yield "  collapsible: true,"
-        yield "  layout: 'form',"
+        if dh.main.value['layout'] == 'hbox':
+            yield "  layout: 'hbox',"
+        else:
+            yield "  layout: 'form',"
         yield "  autoHeight: true,"
         #~ if dh.layout.window_size and dh.layout.window_size[1] == 'auto':
             #~ yield "  autoHeight: true,"
@@ -1350,7 +1361,7 @@ tinymce.init({
         assert tbl.action_name is not None
             #~ raise Exception("20121009 action_name of %r is None" % tbl)
         yield "  action_name: '%s'," % tbl.action_name
-        yield "  ls_url: %s," % py2js(dh.layout._url)
+        #~ 20131004 yield "  ls_url: %s," % py2js(dh.layout._url)
         yield "  window_title: %s," % py2js(tbl.label)
         #~ yield "  layout: 'fit',"
         #~ yield "  auto_save: true,"
