@@ -32,7 +32,7 @@ from lino.core import actions
 from lino.core import model
 
 
-class Duplicate(actions.RowAction):
+class Duplicate(actions.Action):
     """
     Duplicate the row on which it is being executed.
     """
@@ -40,16 +40,20 @@ class Duplicate(actions.RowAction):
     sort_index = 11
     show_in_workflow = False
     readonly = True # like InsertRow. See docs/blog/2012/0726
-    icon_name = 'x-tbar-duplicate'
+    icon_name = 'arrow_divide'
     #~ action_name = 'duplicate'
 
   
+    def is_callable_from(self,caller):
+        return True
+        
     def get_action_permission(self,ar,obj,state):
         if ar.get_user().profile.readonly: 
             return False
         return super(Duplicate,self).get_action_permission(ar,obj,state)
         
-    def run_from_code(self,obj,ar,**known_values):
+    def run_from_code(self,ar,**known_values):
+        obj = ar.selected_rows[0]
         #~ if not isinstance(ar,actions.ActionRequest):
             #~ raise Exception("Expected and ActionRequest but got %r" % ar)
         #~ related = dict()
@@ -133,8 +137,9 @@ class Duplicate(actions.RowAction):
                 
         return new
         
-    def run_from_ui(self,obj,ar,**kw):
-        new = self.run_from_code(obj,ar)
+    def run_from_ui(self,ar,**kw):
+        obj = ar.selected_rows[0]
+        new = self.run_from_code(ar)
         kw = dict()
         kw.update(refresh=True)
         kw.update(message=_("Duplicated %(old)s to %(new)s.") % dict(old=obj,new=new))
