@@ -39,14 +39,16 @@ from django.http import HttpResponse, HttpResponseRedirect, Http404
 from django.utils.encoding import force_unicode
 from django.utils.translation import string_concat
 
+from djangosite.dbutils import dtomy
 
 import lino
 #~ from lino import dd
 
 from lino.core import actions
 from lino.core import fields
+from lino.core import dbutils
 from lino.utils import iif, moneyfmt
-from north import dbutils
+#~ from north import dbutils
 #~ from lino.utils import call_optional_super
 from lino.utils.choosers import chooser
 from lino.utils.appy_pod import Renderer
@@ -247,10 +249,6 @@ class PisaBuildMethod(DjangoBuildMethod):
 
 class SimpleBuildMethod(BuildMethod):
   
-    def get_group(self,elem):
-        #~ return 'doctemplates/' + self.templates_name + '/' + elem.get_templates_group()
-        return elem.get_templates_group()
-  
     def get_template_leaf(self,action,elem):
       
         tpls = action.get_print_templates(self,elem)
@@ -265,7 +263,8 @@ class SimpleBuildMethod(BuildMethod):
         if lang != settings.SITE.DEFAULT_LANGUAGE.django_code:
             name = tpl_leaf[:-len(self.template_ext)] + "_" + lang + self.template_ext
             from lino.utils.config import find_config_file
-            if find_config_file(name,self.get_group(elem)):
+            #~ if find_config_file(name,self.get_group(elem)):
+            if find_config_file(name,elem.get_templates_group()):
                 return name
         return tpl_leaf
             #~ tplfile = os.path.normpath(os.path.join(self.templates_dir,lang,tpl_leaf))
@@ -280,9 +279,10 @@ class SimpleBuildMethod(BuildMethod):
     def get_template_file(self,ar,action,elem):
         from lino.utils.config import find_config_file
         tpl_leaf = self.get_template_leaf(action,elem)
-        tplfile = find_config_file(tpl_leaf,self.get_group(elem))
+        tg = elem.get_templates_group()
+        tplfile = find_config_file(tpl_leaf,tg)
         if not tplfile:
-            raise Warning("No file %s/%s" % (self.get_group(elem),tpl_leaf))
+            raise Warning("No file %s/%s" % (tg,tpl_leaf))
         #~ tplfile = os.path.normpath(os.path.join(self.templates_dir,tpl_leaf))
         return tplfile
         
@@ -433,16 +433,6 @@ def build_method_choices():
 
     
     
-def get_template_choices(elem,bmname):
-    """
-    :param:bmname: the name of a build method.
-    """
-    bm = bm_dict.get(bmname,None)
-    if bm is None:
-        raise Exception("%r : invalid print method name." % bmname)
-    from lino.utils.config import find_template_config_files
-    return find_template_config_files(bm.template_ext,bm.get_group(elem))
-    
 def get_build_method(elem):
     bmname = elem.get_build_method()
     if not bmname:
@@ -472,9 +462,16 @@ class BasePrintAction(actions.Action):
     url_action_name = 'print'
     label = _('Print')
     
-    callable_from = (actions.GridEdit, 
-        actions.ShowDetailAction,
-        actions.ShowEmptyTable) # but not from InsertRow
+    
+    def attach_to_actor(self,actor,name):
+        if not dbutils.resolve_app('system'):
+            return False
+        return super(BasePrintAction,self).attach_to_actor(actor,name)
+    
+    def is_callable_from(self,caller):
+        return isinstance(caller,(actions.GridEdit, 
+            actions.ShowDetailAction,
+            actions.ShowEmptyTable)) # but not from InsertRow
     
     #~ def __init__(self,rpt,*args,**kw):
         #~ self.actor = rpt
@@ -724,19 +721,33 @@ class PrintableType(Model):
     #~ build_method = models.CharField(max_length=20,choices=mixins.build_method_choices())
     #~ template = models.CharField(max_length=200)
     
-    #~ @classmethod
+    @classmethod
     def get_templates_group(cls):
+        """
+        Note that `get_templates_group` is 
+        a class method on `PrintableType`
+        an instance method on `Printable`
+        """
         #~ return cls.templates_group or cls._meta.app_label
         return cls.templates_group # or full_model_name(cls)
         
     @chooser(simple_values=True)
     def template_choices(cls,build_method):
-        #~ from lino.models import get_site_config
+        return cls.get_template_choices(build_method,cls.get_templates_group())
+        
+    @classmethod
+    def get_template_choices(cls,build_method,template_group):
         if not build_method:
-            #~ build_method = get_site_config().default_build_method 
-            #~ build_method = settings.SITE.config.default_build_method 
             build_method = settings.SITE.site_config.default_build_method 
-        return get_template_choices(cls,build_method)
+        #~ return get_template_choices(cls,build_method)
+        bm = bm_dict.get(build_method,None)
+        if bm is None:
+            raise Exception("%r : invalid print method name." % build_method)
+        from lino.utils.config import find_template_config_files
+        #~ return find_template_config_files(bm.template_ext,bm.get_group(elem))
+        return find_template_config_files(bm.template_ext,template_group)
+        
+        
     
 class BasePrintable(object):
     """
@@ -776,18 +787,9 @@ class BasePrintable(object):
         
     def get_printable_context(self,ar,**kw):
         """
-        Defines the following names in your template context:
-        
-        this
-            The printable object instance
-            
-        mtos
-            "amount to string" using :func:`decfmt`
-        fds
-            "format date short", see :func:`north.dbutils.fds`
-        fdm
-            "format date medium", see :func:`north.dbutils.fdm`
+        Defines the certain names of a template context.
         
+        See :doc:`/user/templates_api`.
         
         :class:`lino.modlib.notes.models.Note` extends this.
         """
@@ -795,18 +797,18 @@ class BasePrintable(object):
             return _(s.decode('utf8'))
         from lino import dd
         kw.update(this=self,
-            dtos=dd.dtos, # obsolete
-            dtosl=dbutils.dtosl, # obsolete
-            dtomy=dbutils.dtomy, # obsolete
+            dtos=dd.fds, # obsolete
+            dtosl=dd.fdf, # obsolete
+            dtomy=dtomy, # obsolete
             mtos=decfmt,
-            fds=dbutils.fds,
-            fdm=dbutils.fdm,
-            fdl=dbutils.fdl,
-            fdf=dbutils.fdf,
-            fdmy=dbutils.fdmy,
-            babelattr=dbutils.babelattr,
-            babelitem=dbutils.babelitem,
-            tr=dbutils.babelitem,
+            fds=dd.fds,
+            fdm=dd.fdm,
+            fdl=dd.fdl,
+            fdf=dd.fdf,
+            fdmy=dd.fdmy,
+            babelattr=dd.babelattr,
+            babelitem=settings.SITE.babelitem,
+            tr=settings.SITE.babelitem,
             iif=iif,
             settings=settings,
             ar=ar,
