@@ -11,6 +11,11 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
+"""
+The :xfile:`models.py` for the :mod:`lino.modlib.about` app.
+
+"""
+
 import logging
 logger = logging.getLogger(__name__)
 
