@@ -14,7 +14,7 @@
 
 """
 This module turns Lino into a basic calendar client. 
-To be combined with :attr:`lino.ui.Site.use_extensible`.
+To be combined with :attr:`lino.site.Site.use_extensible`.
 Supports remote calendars.
 Events and Tasks can get attributed to a :attr:`Project <lino.Site.project_model>`.
 
@@ -47,4 +47,4 @@ Events and Tasks can get attributed to a :attr:`Project <lino.Site.project_model
                     #~ yield i
 
 
-  
\ No newline at end of file
+  
