@@ -27,7 +27,7 @@ TABLE2 contains 4-letter codes for countries that no longer exist.
 This is mostly based on <http://www.davros.org/misc/iso3166.html>,
 but one country (DEDE) was added.
 
-Another fixture, :mod:`welfare.modlib.statbel.fixtures.inscodes`,
+Another fixture, :mod:`lino.modlib.statbel.fixtures.inscodes`,
 extends this data by attaching Belgian INS codes to these countries.
 
 """
