@@ -84,15 +84,20 @@ def objects():
         return City(country=BE,type=CityTypes.province,
             **babel_values('name',de=de,fr=fr,nl=nl,en=fr))
     
-    def be_city(zip_code,de,fr,nl,en,**kw):
+    def be_city(zip_code,de=None,fr=None,nl=None,en=None,**kw):
         kw.update(babel_values('name',de=de,fr=fr,nl=nl,en=en))
-        return City(country=BE,zip_code=zip_code,type=CityTypes.city,**kw)
+        kw.setdefault('type',CityTypes.city)
+        return City(country=BE,zip_code=zip_code,**kw)
             
     yield be_province("Antwerpen","Anvers","Antwerpen")
     yield be_province("Luxemburg","Luxembourg","Luxemburg")
-    yield be_province("Limburg","Limbourg","Limburg")
     yield be_province("Namür","Namur","Namen")
     
+    prov = be_province("Limburg","Limbourg","Limburg")
+    yield prov
+    yield make_city('BE','Aalst-bij-Sint-Truiden',zip_code='3800',parent=prov,type=CityTypes.village)
+    
+    
     prov = be_province("Lüttich","Liège","Luik")
     yield prov
     yield be_city('4000',"Lüttich","Liège","Luik","Liège",parent=prov)
@@ -100,11 +105,27 @@ def objects():
     yield be_city('4760',"Büllingen","Bullange","Büllingen","Büllingen",parent=prov)
     yield be_city('4780',"Sankt Vith","Saint-Vith","Sankt Vith","Sankt Vith",parent=prov)
     yield be_city('4780',"Recht","Recht","Recht","Recht",parent=prov)
+    yield be_city('4837',"Baelen","Baelen","Baelen","Baelen",parent=prov)
+
     
     yield be_province("Hennegau","Hainaut","Henegouwen")
     yield be_province("Wallonisch-Brabant","Brabant wallon","Waals-Brabant")
     yield be_province("Flämisch-Brabant","Brabant flamant","Vlaams-Brabant")
-    yield be_province("Ostflandern","Flandre de l'Est","Oost-Vlaanderen")
+    
+    prov = be_province("Ostflandern","Flandre de l'Est","Oost-Vlaanderen")
+    yield prov
+    
+    aalst = be_city('9300',"Aalst","Alost","Aalst","Aalst",parent=prov)
+    yield aalst
+    yield be_city('9308',name="Gijzegem",parent=aalst,type=CityTypes.village)
+    yield be_city('9310',name="Baardegem ",parent=aalst,type=CityTypes.village)
+    yield be_city('9320',name="Erembodegem",parent=aalst,type=CityTypes.village)
+    yield be_city('9310',name="Herdersem",parent=aalst,type=CityTypes.village)
+    yield be_city('9308',name="Hofstade",parent=aalst,type=CityTypes.village)
+    yield be_city('9310',name="Meldert",parent=aalst,type=CityTypes.village)
+    yield be_city('9320',name="Nieuwerkerken",parent=aalst,type=CityTypes.village)
+    yield be_city('9310',name="Moorsel",parent=aalst,type=CityTypes.village)
+    
     yield be_province("Westflandern","Flandre de l'Ouest","West-Vlaanderen")
     
     yield be_city('1000',"Brüssel","Bruxelles","Brussel","Brussels")
