@@ -66,8 +66,8 @@ class VoucherType(dd.Choice):
         model = dd.resolve_model(model)
         self.model = model
         value = dd.full_model_name(model)
-        text = model._meta.verbose_name + ' (%s.%s)' % (
-            model.__module__,model.__name__)
+        text = model._meta.verbose_name + ' (%s)' % dd.full_model_name(model)
+        #~ text = model._meta.verbose_name + ' (%s.%s)' % (model.__module__,model.__name__)
         name = None
         super(VoucherType,self).__init__(value,text,name)
         
@@ -93,9 +93,6 @@ class VoucherTypes(dd.ChoiceList):
 
 
 
-class DebitOrCreditField(models.BooleanField):
-    pass
-    
 class MatchField(models.CharField):
     def __init__(self,verbose_name=None,**kw):
         if verbose_name is None:
@@ -140,7 +137,7 @@ class Journal(dd.BabelNamed,mixins.Sequenced,mixins.PrintableType):
     trade_type = vat.TradeTypes.field(blank=True)
     #~ doctype = models.IntegerField() #choices=DOCTYPE_CHOICES)
     voucher_type = VoucherTypes.field() 
-    force_sequence = models.BooleanField(default=False)
+    force_sequence = models.BooleanField(_("Force chronological sequence"),default=False)
     #~ total_based = models.BooleanField(_("Voucher entry based on total amount"),default=False)
     chart = dd.ForeignKey('accounts.Chart')
     #~ chart = dd.ForeignKey('accounts.Chart',blank=True,null=True)
@@ -149,7 +146,7 @@ class Journal(dd.BabelNamed,mixins.Sequenced,mixins.PrintableType):
     #~ pos = models.IntegerField()
     #~ printed_name = models.CharField(max_length=100,blank=True)
     printed_name = dd.BabelCharField(max_length=100,blank=True)
-    dc = DebitOrCreditField(default=None)
+    dc = accounts.DebitOrCreditField()
     
     @dd.chooser()
     def account_choices(self,chart):
@@ -188,6 +185,7 @@ class Journal(dd.BabelNamed,mixins.Sequenced,mixins.PrintableType):
         except TypeError,e:
             #~ print 20100804, cl
             raise
+        doc.on_create(None)
         #~ doc.full_clean()
         #~ doc.save()
         return doc
@@ -200,7 +198,7 @@ class Journal(dd.BabelNamed,mixins.Sequenced,mixins.PrintableType):
         
         
     def get_next_number(self,voucher):
-        self.save()
+        #~ self.save() # 20131005 why was this?
         cl = self.get_doc_model()
         d = cl.objects.filter(journal=self,year=voucher.year).aggregate(
             models.Max('number'))
@@ -249,19 +247,28 @@ class Journal(dd.BabelNamed,mixins.Sequenced,mixins.PrintableType):
             if doc.number + 1 != self.get_next_number(doc):
                 return _("%s is not the last voucher in journal" % unicode(doc))
 
-    def get_templates_group(self):
-        return model_group(self.voucher_type.model)
+    @dd.chooser(simple_values=True)
+    def template_choices(cls,build_method,voucher_type):
+        """
+        Overrides PrintableType.template_choices because 
+        """
+        if not voucher_type: return []
+        print 20131006, voucher_type
+        template_group = model_group(voucher_type.model)
+        return cls.get_template_choices(build_method,template_group)
+        
+        
 
 
 class Journals(dd.Table):
     model = Journal
     order_by = ["seqno"]
-    column_names = "ref:5 trade_type voucher_type force_sequence name * seqno id"
+    column_names = "ref:5 name trade_type voucher_type force_sequence * seqno id"
     detail_layout = """
-    ref trade_type voucher_type 
-    force_sequence account seqno id
+    ref:5 trade_type seqno id voucher_type:10
+    force_sequence account dc build_method template
     name
-    build_method  printed_name
+    printed_name
     """
     insert_layout = dd.FormLayout("""
     ref name
@@ -290,8 +297,9 @@ class Voucher(mixins.UserAuthored,mixins.Registrable):
     This model is subclassed by sales.Invoice, ledger.AccountInvoice, 
     finan.Statement etc...
     
-    It is *not* abstract because we have a ForeignKey to Voucher in 
-    Movement and we want one Movement model for all ledger movements.
+    It is *not* abstract so that :class:`Movement` can have a ForeignKey 
+    to a Voucher. Otherwise we would have to care ourselves about data 
+    integrity, and we couln't make queries on `voucher__xxx`.
     
     """
     class Meta:
@@ -349,12 +357,13 @@ class Voucher(mixins.UserAuthored,mixins.Registrable):
             
         
     def __unicode__(self):
-        if self.number is None:
-            return "%s #%s (not registered)" % (
-                unicode(self.journal.voucher_type.model._meta.verbose_name),self.id)
-        if self.journal.ref:
-            return "%s#%s" % (self.journal.ref,self.number)
-        return "#%s (%s %s)" % (self.number,self.journal,self.year)
+        return "%s#%s" % (self.journal.ref,self.id)
+        #~ if self.number is None:
+            #~ return "%s #%s (not registered)" % (
+                #~ unicode(self.journal.voucher_type.model._meta.verbose_name),self.id)
+        #~ if self.journal.ref:
+            #~ return "%s#%s" % (self.journal.ref,self.number)
+        #~ return "#%s (%s %s)" % (self.number,self.journal,self.year)
         
     def get_default_match(self):
         #~ return "%s#%s" % (self.journal.ref,self.number)
@@ -368,13 +377,16 @@ class Voucher(mixins.UserAuthored,mixins.Registrable):
         """
         delete any existing movements and re-create them
         """
-        if self.year is None:
-            self.year = FiscalYears.from_date(self.date)
+        #~ if self.year is None:
+        self.year = FiscalYears.from_date(self.date)
         if self.number is None:
             self.number = self.journal.get_next_number(self)
         assert self.number is not None
         self.movement_set.all().delete() 
+        seqno = 0
         for m in self.get_wanted_movements():
+            seqno += 1
+            m.seqno = seqno
             m.full_clean()
             m.save()
         super(Voucher,self).register(ar)
@@ -453,8 +465,9 @@ class Voucher(mixins.UserAuthored,mixins.Registrable):
         #~ return super(Voucher,self).get_row_permission(ar,state,ba)
 
     def get_mti_child(self):
-        return self.journal.voucher_type.model.objects.get(
-            journal=self.journal,number=self.number,year=self.year)
+        return self.journal.voucher_type.model.objects.get(id=self.id)
+        #~ return self.journal.voucher_type.model.objects.get(
+            #~ journal=self.journal,number=self.number,year=self.year)
         #~ m = self.journal.voucher_type.model
         #~ return m.objects.get(pk=self.pk)
         
@@ -509,53 +522,15 @@ class ByJournal(dd.Table):
 
 
         
-class Matchable(dd.Model):
-    
-    class Meta: 
-        abstract = True
-        
-    match = MatchField(blank=True)
-    #~ match = dd.ForeignKey('ledger.Movement',verbose_name=_("Match"),blank=True,null=True)
-    
-    #~ @dd.chooser()
-    #~ def match_choices(cls,partner):
-        #~ d = {}
-        #~ qs = Movement.objects.filter(partner=partner,satisfied=False)
-        #~ for m in qs:
-            #~ i = d.setdefault(m.get_match(),[])
-            #~ i.append(m)
-        #~ choices = []
-        #~ for k,lst in d.items():
-            #~ amount = ZERO
-            #~ text = ", ".join([i.select_text() for i in lst])
-            #~ for i in lst:
-                #~ amount += iif(i.dc,1,-1) * i.amount
-            #~ text += ' ' + unicode(amount)
-            #~ choices.append((k,text))
-        #~ return choices
-        
-        
-        
-    @dd.chooser(simple_values=True)
-    def match_choices(cls,partner):
-        #~ DC = voucher.journal.dc
-        #~ choices = []
-        qs = Movement.objects.filter(partner=partner,satisfied=False)
-        qs = qs.order_by('voucher__date')
-        #~ qs = qs.distinct('match')
-        return qs.values_list('match',flat=True)
-        
-        for mvt in qs:
-            choices.append(Match(DC,partner,mvt.match))
-        return choices
-        
-    #~ def get_match_display(self,m):
-        #~ return repr(m)
-    
-
 
     
-class Movement(mixins.Sequenced,Matchable):
+#~ class Movement(mixins.Sequenced,Matchable):
+
+#~ class Movement(Matchable):
+class Movement(dd.Model):
+    """
+    An accounting movement in the ledger.
+    """
   
     allow_cascaded_delete = ['voucher']
     
@@ -563,18 +538,40 @@ class Movement(mixins.Sequenced,Matchable):
         verbose_name = _("Movement")
         verbose_name_plural = _("Movements")
         
+        
+        
     voucher = models.ForeignKey(Voucher)
+    
+    seqno = models.IntegerField(
+        #~ blank=True,null=False,
+        verbose_name=_("Seq.No."))
+        
+    
     #~ pos = models.IntegerField("Position",blank=True,null=True)
     account = dd.ForeignKey(accounts.Account)
     partner = dd.ForeignKey(partner_model,blank=True,null=True)
     amount = dd.PriceField(default=0)
-    dc = DebitOrCreditField()
+    dc = accounts.DebitOrCreditField()
+    
+    match = MatchField(blank=True)
+    
     satisfied = models.BooleanField(_("Satisfied"),default=False)
     #~ match = dd.ForeignKey('self',verbose_name=_("Match"),blank=True,null=True)
     #~ is_credit = models.BooleanField(_("Credit"),default=False)
     #~ debit = dd.PriceField(default=0)
     #~ credit = dd.PriceField(default=0)
     
+    
+    @dd.chooser(simple_values=True)
+    def match_choices(cls,partner,account):
+        #~ DC = voucher.journal.dc
+        #~ choices = []
+        qs = cls.objects.filter(partner=partner,account=account,satisfied=False)
+        qs = qs.order_by('voucher__date')
+        #~ qs = qs.distinct('match')
+        return qs.values_list('match',flat=True)
+    
+    
     #~ def full_clean(self,*args,**kw):
         #~ if not self.match:
             #~ self.match = self.voucher.get_default_match()
@@ -621,40 +618,111 @@ class Movement(mixins.Sequenced,Matchable):
         
 
 class Movements(dd.Table): 
+    """
+    The table of all movements, 
+    displayed by :menuselection:`Explorer --> Accounting --> Movements`.
+    This is also the base class for 
+    :class:`MovementsByVoucher`,
+    :class:`MovementsByAccount`
+    and
+    :class:`MovementsByPartner`
+    and defines e.g. filtering parameters.
+    
+    """
     model = Movement
     column_names = 'voucher_link account debit credit *'
     editable = False
+    parameters = dd.ObservedPeriod(
+        pyear=FiscalYears.field(blank=True),
+        ppartner=models.ForeignKey(partner_model,blank=True,null=True),
+        paccount=models.ForeignKey('accounts.Account',blank=True,null=True),
+        pjournal=JournalRef(blank=True),
+        cleared=dd.YesNo.field(_("Show cleared movements"),blank=True))
+    params_layout = """
+    start_date end_date cleared 
+    pjournal pyear ppartner paccount"""
+    
+    @classmethod
+    def get_request_queryset(cls,ar):
+        qs = super(Movements,cls).get_request_queryset(ar)
+        
+        if ar.param_values.cleared == dd.YesNo.yes:
+            qs = qs.filter(satisfied=True)
+        elif ar.param_values.cleared == dd.YesNo.no:
+            qs = qs.filter(satisfied=False)
+            
+        if ar.param_values.ppartner:
+            qs = qs.filter(partner=ar.param_values.ppartner)
+        if ar.param_values.paccount:
+            qs = qs.filter(account=ar.param_values.paccount)
+        if ar.param_values.pyear:
+            qs = qs.filter(voucher__year=ar.param_values.pyear)
+        if ar.param_values.pjournal:
+            qs = qs.filter(voucher__journal=ar.param_values.pjournal)
+        return qs
     
 class MovementsByVoucher(Movements):
     master_key = 'voucher'
     column_names = 'seqno account debit credit match satisfied'
-    #~ editable = False
     auto_fit_column_widths = True
     
 class MovementsByPartner(Movements):
     master_key = 'partner'
     order_by = ['-voucher__date']
     column_names = 'voucher__date voucher_link debit credit account match satisfied'
-    #~ editable = False
     auto_fit_column_widths = True
     
-class Match(object):
+    @classmethod
+    def param_defaults(cls,ar,**kw):
+        kw = super(MovementsByPartner,cls).param_defaults(ar,**kw)
+        kw.update(cleared=dd.YesNo.no)
+        kw.update(pyear='')
+        return kw
+        
+    
+class MovementsByAccount(Movements):
+    master_key = 'account'
+    order_by = ['-voucher__date']
+    column_names = 'voucher__date voucher_link debit credit partner match satisfied'
+    auto_fit_column_widths = True
+    
+    @classmethod
+    def param_defaults(cls,ar,**kw):
+        kw = super(MovementsByAccount,cls).param_defaults(ar,**kw)
+        if ar.master_instance is not None and ar.master_instance.clearable:
+            kw.update(cleared=dd.YesNo.no)
+            kw.update(pyear='')
+        return kw
+    
+class DueMovement(object):
     """
-    Volatile object representing a group of movements
+    Volatile object representing a group of "matching" movements.
+    
+    The "matching" movements of a given movement are those who share 
+    the same `match`, `partner` and `account`.
+    
+    These movements are themselves grouped into "debts" and "payments".
+    
+    The value of `dc` specifies whether I mean *my* debts and payments 
+    (towards that partner) or those *of the partner* (towards me).
+    
     """
-    def __init__(self,dc,partner,match):
+    def __init__(self,dc,mvt):
         self.dc = dc
-        self.partner = partner
-        self.match = match
+        self.partner = mvt.partner
+        self.account = mvt.account
+        self.match = mvt.match
+        self.pk = self.id = mvt.id
+        
         self.debts = []
-        self.received = []
+        self.payments = []
         self.balance = ZERO
         self.due_date = None
         self.trade_type = None
         self.has_unsatisfied_movement = False
         self.has_satisfied_movement = False
         
-        qs = Movement.objects.filter(partner=partner,match=match)
+        qs = Movement.objects.filter(partner=self.partner,account=self.account,match=self.match)
         for mvt in qs.order_by('voucher__date'):
             self.collect(mvt)
     
@@ -674,80 +742,153 @@ class Match(object):
             if self.due_date is None or due_date < self.due_date:
                 self.due_date = due_date
         else:
-            self.received.append(mvt)
+            self.payments.append(mvt)
             self.balance -= mvt.amount
     
     def update_satisfied(self):
-        satisfied = self.balance != ZERO
+        satisfied = self.balance == ZERO
         if satisfied:
             if not self.has_unsatisfied_movement: return 
         else:
             if not self.has_satisfied_movement: return 
-        for m in self.debts + self.received:
+        for m in self.debts + self.payments:
             if m.satisfied != satisfied:
                 m.satisfied = satisfied
                 m.save()
                 
-def get_partner_matches(partner,dc,**flt):
-    qs = Movement.objects.filter(partner=partner,**flt)
+def get_due_movements(dc,**flt):
+    if dc is None: 
+        return
+    qs = Movement.objects.filter(**flt)
     qs = qs.order_by('voucher__date')
-    if False: # DISTINCT ON fields not supported
-        qs = qs.distinct('match') 
-        for mvt in qs:
-            yield Match(cls.DUE_DC,partner,mvt.match)
-    else:
-        #~ logger.info("20130921 %s %s",partner,qs)
-        found = set()
-        for mvt in qs:
-            if not mvt.match in found:
-                found.add(mvt.match)
-                yield Match(dc,partner,mvt.match)
+    #~ logger.info("20130921 %s %s",partner,qs)
+    matches_by_account  = dict()
+    for mvt in qs:
+        k = (mvt.account,mvt.partner)
+        matches = matches_by_account.setdefault(k,set())
+        if not mvt.match in matches:
+            matches.add(mvt.match)
+            yield DueMovement(dc,mvt)
         
     
-class DuePaymentsByPartner(dd.VirtualTable):
+class ExpectedMovements(dd.VirtualTable):
     """
-    Due Payements is the table to print in a Payment Reminder.
-    Usually this table has one row per sales invoice which is not completely paid.
-    But several invoices ("debts") may be grouped by match.
+    Subclassed by finan.
     """
-    
-    master = 'contacts.Partner'
-    column_names = 'match due_date balance debts received'
+    label = _("Due")
+    #~ column_names = 'match due_date debts payments balance'
+    column_names = 'due_date:15 balance debts payments'
     auto_fit_column_widths = True
+    parameters = dd.ParameterPanel(
+        date_until=models.DateField(_("Date until"),blank=True,null=True),
+        trade_type=vat.TradeTypes.field(blank=True))
+        #~ journal=dd.ForeignKey(Journal,blank=True))
+        #~ dc=accounts.DebitOrCreditField(default=accounts.DEBIT))
+    params_layout = "trade_type date_until"
     
-    DUE_DC = accounts.DEBIT
-    
+    #~ DUE_DC = accounts.DEBIT
     
     @classmethod
-    def get_data_rows(cls,ar):
-        partner = ar.master_instance
-        if partner is None: return 
-        return get_partner_matches(cls.DUE_DC,partner,satisfied=False)
+    def get_dc(cls,ar=None):
+        return accounts.DEBIT
         
+    @classmethod
+    def get_data_rows(cls,ar,**flt):
+        #~ if ar.param_values.journal: 
+            #~ pass
+        if ar.param_values.trade_type: 
+            flt.update(account=ar.param_values.trade_type.get_partner_account())
+        if ar.param_values.date_until is not None:
+            flt.update(voucher__date__lte=ar.param_values.date_until)
+        return get_due_movements(cls.get_dc(ar),**flt)
+        
+    @classmethod
+    def get_pk_field(self):
+        return Movement._meta.pk
+        
+    @classmethod
+    def get_row_by_pk(cls,ar,pk):
+        mvt = Movement.objects.get(pk=pk)
+        return cls.get_row_for(mvt,ar)
+        
+    @classmethod
+    def get_row_for(cls,mvt,ar):
+        return DueMovement(cls.get_dc(ar),mvt)
+    
     @dd.displayfield(_("Match"))
     def match(self,row,ar):
         return row.match
             
-    @dd.displayfield(_("Due date"))
+    @dd.virtualfield(models.DateField(_("Due date"),
+        help_text=_("Due date of the eldest debt in this match group")))
     def due_date(self,row,ar):
         return row.due_date
             
-    @dd.displayfield(_("Due"))
+    @dd.displayfield(_("Debts"),help_text=_("List of invoices in this match group"))
     def debts(self,row,ar):
         #~ return ", ".join([ar.obj2html(i,i.select_text()) for i in row.debts])
         #~ return join_elems([ar.obj2html(i.voucher,i.select_text()) for i in row.debts])
-        return join_elems([ar.obj2html(i.voucher.get_mti_child()) for i in row.debts])
+        return E.p(*join_elems([ar.obj2html(i.voucher.get_mti_child()) for i in row.debts]))
             
-    @dd.displayfield(_("Received"))
-    def received(self,row,ar):
-        #~ return ", ".join([ar.obj2html(i,i.select_text()) for i in row.received])
-        #~ return join_elems([ar.obj2html(i.voucher,i.select_text()) for i in row.received])
-        return join_elems([ar.obj2html(i.voucher.get_mti_child()) for i in row.received])
+    @dd.displayfield(_("Payments"),help_text=_("List of payments in this match group"))
+    def payments(self,row,ar):
+        #~ return ", ".join([ar.obj2html(i,i.select_text()) for i in row.payments])
+        #~ return join_elems([ar.obj2html(i.voucher,i.select_text()) for i in row.payments])
+        return E.p(*join_elems([ar.obj2html(i.voucher.get_mti_child()) for i in row.payments]))
         
     @dd.virtualfield(dd.PriceField(_("Balance")))
     def balance(self,row,ar):
         return row.balance
             
+    @dd.virtualfield(dd.ForeignKey('contacts.Partner'))
+    def partner(self,row,ar):
+        return row.partner
+            
+    @dd.virtualfield(dd.ForeignKey('accounts.Account'))
+    def account(self,row,ar):
+        return row.account
+            
+    
+    
+class DuePaymentsByAccount(ExpectedMovements):
+    master = 'accounts.Account'
+    
+    @classmethod
+    def get_data_rows(cls,ar,**flt):
+        account = ar.master_instance
+        if account is None: return []
+        if not account.clearable : return []
+        #~ return get_due_movements(cls.DUE_DC,account=account,satisfied=False)
+        flt.update(satisfied=False,account=account)
+        # ignore trade_type to avoid overriding account
+        ar.param_values.trade_type = None
+        return super(DuePaymentsByPartner,cls).get_data_rows(ar,**flt)
+        
+dd.inject_action('accounts.Account',due=dd.ShowSlaveTable(DuePaymentsByAccount))
+    
+class DuePaymentsByPartner(ExpectedMovements):
+    """
+    Due Payements is the table to print in a Payment Reminder.
+    Usually this table has one row per sales invoice which is not fully paid.
+    But several invoices ("debts") may be grouped by match.
+    If the partner has purchase invoices, these are deduced from the balance.
+    """
+    master = 'contacts.Partner'
+    #~ column_names = 'due_date debts payments balance'
+    
+    @classmethod
+    def get_dc(cls,ar=None):
+        return accounts.CREDIT
+        
+    @classmethod
+    def get_data_rows(cls,ar,**flt):
+        partner = ar.master_instance
+        if partner is None: return []
+        flt.update(satisfied=False,partner=partner)
+        return super(DuePaymentsByPartner,cls).get_data_rows(ar,**flt)
+
+dd.inject_action('contacts.Partner',due=dd.ShowSlaveTable(DuePaymentsByPartner))
+        
 
 
 
@@ -764,7 +905,38 @@ add('40',_("Paid"),'paid',editable=False)
 #~ InvoiceStates.draft.add_transition(_("Deregister"),states='registered paid')
 #~ InvoiceStates.registered.add_transition(_("Register"),states='draft')
     
+class Matchable(dd.Model):
+    """
+    Base class for :class:`AccountInvoice`
+    (and e.g. `sales.Invoice`, `finan.DocItem`)
+    
+    Adds a field `match` and a chooser for it.
+    Requires a field `partner`.
+    """
+    
+    class Meta: 
+        abstract = True
+        
+    match = MatchField(blank=True)
+        
+    @dd.chooser(simple_values=True)
+    def match_choices(cls,partner):
+        #~ DC = voucher.journal.dc
+        #~ choices = []
+        qs = Movement.objects.filter(partner=partner,satisfied=False)
+        qs = qs.order_by('voucher__date')
+        #~ qs = qs.distinct('match')
+        return qs.values_list('match',flat=True)
+        
+    
+
+
+
 class AccountInvoice(vat.VatDocument,Voucher,Matchable):
+    """
+    An invoice for which the user enters just the bare accounts and 
+    amounts (not e.g. products, quantities, discounts).
+    """
     
     class Meta:
         verbose_name = _("Invoice")
@@ -783,7 +955,6 @@ class AccountInvoice(vat.VatDocument,Voucher,Matchable):
         return self.due_date or self.date
         
         
-    
 
 
 class VoucherItem(dd.Model):
@@ -837,14 +1008,15 @@ class InvoiceDetail(dd.FormLayout):
     MovementsByVoucher
     """,label=_("Ledger"))
     
+    
 class Invoices(dd.Table):
+    model = AccountInvoice
+    order_by = ["date","id"]
+    column_names = "date id number partner total_incl user *" 
     parameters = dict(
         pyear=FiscalYears.field(blank=True),
         ppartner=models.ForeignKey(partner_model,blank=True,null=True),
         pjournal=JournalRef(blank=True))
-    model = AccountInvoice
-    order_by = ["date","id"]
-    column_names = "date id number partner total_incl user *" 
     params_layout = "pjournal pyear ppartner"
     detail_layout = InvoiceDetail()
     insert_layout = dd.FormLayout("""
@@ -863,6 +1035,12 @@ class Invoices(dd.Table):
             qs = qs.filter(journal=ar.param_values.pjournal)
         return qs
     
+    @classmethod
+    def param_defaults(cls,ar,**kw):
+        kw = super(Invoices,cls).param_defaults(ar,**kw)
+        kw.update(pyear=FiscalYears.from_date(datetime.date.today()))
+        return kw
+        
     
 
 
@@ -973,11 +1151,20 @@ def customize_accounts():
             tt.name+'_allowed',
             models.BooleanField(verbose_name=tt.text))
 
+    dd.inject_field('accounts.Account',
+        'clearable',models.BooleanField(_("Clearable"),default=False))
+        
+        
+    
 customize_accounts()
 
 
 
 def update_partner_satisfied(p):
-    for m in get_partner_matches(accounts.DEBIT,p):
+    """
+    This is called when a voucher has been (un)registered  on each 
+    partner for whom the voucher caused at least one movement.
+    """
+    for m in get_due_movements(accounts.DEBIT,partner=p):
         m.update_satisfied()
         
