@@ -12,7 +12,7 @@
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
 """
-The models module of the :mod:`lino.modlib.system` app.
+The `models` module of the :mod:`lino.modlib.system` app.
 """
 
 import logging
@@ -50,18 +50,18 @@ from lino.utils.xmlgen import html as xghtml
 #~ from lino.core.changes import Change, Changes, ChangesByObject
 
 
-#~ class BuildLinoJS(dd.RowAction):
-class BuildSiteCache(dd.RowAction):
+#~ class BuildLinoJS(dd.CustomAction):
+class BuildSiteCache(dd.Action):
     """
     Rebuild the site cache.
     This action is available on :class:`About`.
     """
     label = _("Rebuild site cache")
     url_action_name = "buildjs"
-    def run_from_ui(self,elem,ar):
+    def run_from_ui(self,ar):
         #~ rr.confirm(_("Are you sure?"))
         #~ rr.confirm(_("Are you really sure?"))
-        settings.SITE.ui.build_site_cache(True)
+        settings.SITE.ui.ext_renderer.build_site_cache(True)
         return ar.success(
             """\
 Seems that it worked. Refresh your browser. 
@@ -76,9 +76,8 @@ class SiteConfigManager(models.Manager):
     def get(self, *args, **kwargs):
         return settings.SITE.site_config
 
-    
 
-    
+
 class SiteConfig(dd.Model):
     """
     This model should have exactly one instance, 
@@ -212,7 +211,7 @@ if settings.SITE.is_installed('contenttypes'):
                       #~ logger.info("20120205 adding(%r)",cl)
                       ct = contenttypes.ContentType.objects.get_for_model(cl)
                       #~ chunks.append(settings.SITE.ui.ext_renderer.href_to(ct,unicode(cl._meta.verbose_name)))
-                      chunks.append(ar.href_to(ct,unicode(cl._meta.verbose_name)))
+                      chunks.append(ar.obj2html(ct,unicode(cl._meta.verbose_name)))
           if obj is not None:
               #~ add(obj.model_class())
               for b in obj.model_class().__bases__:
@@ -252,7 +251,7 @@ if settings.SITE.is_installed('contenttypes'):
                       l.append(f.name)
               for f in meta.many_to_many: l.append(f.name)
               for f in meta.virtual_fields: l.append(f.name)
-              for a in model._lino_default_table.get_actions():
+              for a in model.get_default_table().get_actions():
                   l.append(a.action.action_name)
               l.sort()
           return l
@@ -267,7 +266,7 @@ if settings.SITE.is_installed('contenttypes'):
           m = self.content_type.model_class()
           #~ if isinstance(m,UnresolvedModel):
               #~ return str(m)
-          de = m._lino_default_table.get_data_elem(self.field)
+          de = m.get_default_table().get_data_elem(self.field)
           if isinstance(de,models.Field):
               #~ return unicode(de.verbose_name)
               return "%s (%s)" % (unicode(de.verbose_name), unicode(_("database field")))
@@ -307,7 +306,7 @@ if settings.SITE.user_model:
         description = dd.RichTextField(_("Description"),
             blank=True,null=True,format='plain')
             #~ blank=True,null=True,format='html')
-        team = models.ForeignKey('users.Team',blank=True,null=True,
+        team = dd.ForeignKey('users.Team',blank=True,null=True,
             help_text=_("If not empty, then this template is reserved to members of this team."))
         text = dd.RichTextField(_("Template Text"),
             blank=True,null=True,format='html')
@@ -339,6 +338,7 @@ if settings.SITE.user_model:
 
 class Home(mixins.EmptyTable):
     """
+    Deprecated. Use :xfile:`admin_main.html` instead.
     This is the "home page" or "welcome screen", the window to be displayed 
     when no other window is opened.
     """
@@ -369,8 +369,8 @@ class Home(mixins.EmptyTable):
             chunks = []
             for mi in quicklinks.items:
                 chunks.append(' ')
-                chunks.append(settings.SITE.ui.ext_renderer.window_action_button(
-                  ar,mi.bound_action))
+                chunks.append(ar.window_action_button(mi.bound_action))
+                #~ chunks.append(settings.SITE.ui.ext_renderer.window_action_button(ar,mi.bound_action))
             return xghtml.E.p('Quick Links:',*chunks)
       
     #~ @dd.virtualfield(dd.HtmlBox())
@@ -385,34 +385,28 @@ class Home(mixins.EmptyTable):
         
     @dd.virtualfield(dd.HtmlBox(_('Welcome')))
     def welcome(cls,self,ar):
+        
         #~ MAXITEMS = 2
         u = ar.get_user()
         story = []
         
         if u.profile.authenticated:
           
-            intro = [_("Hi, "),u.first_name,'! ']
+            intro = [_("Hi, %(user)s!") % dict(user=u.first_name)]
             story.append(xghtml.E.p(*intro))
             warnings = []
             
             #~ for T in (MySuggestedCoachings,cal.MyTasksToDo):
             for table,text in settings.SITE.get_todo_tables(ar):
-                r = table.request(user=u)
-                #~ r = T.request(subst_user=u)
-                #~ r = ar.spawn(T)
-                if r.get_total_count() != 0:
-                    #~ for obj in r.data_iterator[-MAXITEMS]:
-                        #~ chunks = [obj.summary_row(ar)]
-                        #~ sep = ' : '
-                        #~ for a in T.get_workflow_actions(ar,obj):
-                            #~ chunks.append(sep)
-                            #~ chunks.append(ar.row_action_button(obj,a))
-                            #~ sep = ', '
-                    
-                    warnings.append(xghtml.E.li(
-                        ar.href_to_request(r,text % r.get_total_count())))
-                        #~ _("You have %d entries in ") % r.get_total_count(),
-                        #~ ar.href_to_request(r,label)))
+                if table.get_view_permission(u.profile):
+                    r = table.request(user=u)
+                    #~ r = T.request(subst_user=u)
+                    #~ r = ar.spawn(T)
+                    if r.get_total_count() != 0:
+                        warnings.append(xghtml.E.li(
+                            ar.href_to_request(r,text % r.get_total_count())))
+                            #~ _("You have %d entries in ") % r.get_total_count(),
+                            #~ ar.href_to_request(r,label)))
             
             #~ warnings.append(xghtml.E.li("Test 1"))
             #~ warnings.append(xghtml.E.li("Second test"))
@@ -455,8 +449,6 @@ def setup_main_menu(site,ui,profile,m):
     #~ office.add_action(MyTextFieldTemplates)
     pass
 
-def setup_my_menu(site,ui,profile,m): pass
-  
 def setup_config_menu(site,ui,profile,m):
     office = m.add_menu("office",OFFICE_MODULE_LABEL)
     system = m.add_menu("system",SYSTEM_USER_LABEL)
