@@ -15,9 +15,9 @@
 from lino.projects.std.settings import *
 #~ from lino.projects.presto import __version__, __url__, __name__
 
-from lino.modlib import ledger
+from lino.modlib import vat
 
-class Site(Site,ledger.SiteMixin):
+class Site(Site,vat.SiteMixin):
 
     #~ title = __name__
     verbose_name = "Lino Presto"
@@ -41,11 +41,12 @@ class Site(Site,ledger.SiteMixin):
     
     override_modlib_models = [
       'contacts.Person','contacts.Company',
-      'households.Household']
+      'households.Household',
+      'sales.Invoice', 'sales.InvoiceItem']
     
       
-    def get_main_action(self,user):
-        return self.modules.lino.Home.default_action
+    #~ def get_main_action(self,user):
+        #~ return self.modules.lino.Home.default_action
         
     #~ def setup_quicklinks(self,ui,user,tb):
         #~ tb.add_action(self.modules.contacts.Persons.detail_action)
@@ -95,8 +96,8 @@ class Site(Site,ledger.SiteMixin):
         yield 'lino.modlib.accounts'
         yield 'lino.modlib.ledger'
         yield 'lino.modlib.vat'
-        #~ 'lino.modlib.journals',
-        yield 'lino.modlib.sales'
+        #~ yield 'lino.modlib.sales'
+        yield 'lino.modlib.auto.sales'
         #~ 'lino.modlib.projects',
         yield 'lino.modlib.blogs'
         yield 'lino.modlib.tickets'
@@ -114,3 +115,4 @@ class Site(Site,ledger.SiteMixin):
 
 SITE = Site(globals()) 
 
+
