@@ -1,5 +1,5 @@
 SETUP_INFO = dict(name = 'lino',
-  version = '1.6.12', # released 20130911
+  version = '1.6.13', # released 20131007(?)
   install_requires = ['North','djangosite','odfpy','jinja2','appy','pytidylib','PyYAML'],
   description = "A framework for writing desktop-like web applications using Django and ExtJS",
   license = 'GPL',
@@ -118,6 +118,8 @@ lino.modlib.declarations
 lino.modlib.events
 lino.modlib.events.fixtures
 lino.modlib.events.tests
+lino.modlib.statbel
+lino.modlib.statbel.fixtures
 lino.modlib.system
 lino.modlib.system.fixtures
 lino.modlib.system.tests
