@@ -14,8 +14,52 @@
 
 """
 This defines the :class:`Site` class.
+It has a lot of class attributes which may be 
+overridden by the application developer and/or the local site 
+administrator.
+
+Here is a list of Lino-specific settings. 
+The settings inherited :class:`north.Site` 
+and :class:`djangosite.Site` are documented there.
+
+.. setting:: config_id
+
+The primary key of the one and only `SiteConfig` instance of this 
+SITE. Default value is 1.
+
+This is Lino's equivalent of Django's :setting:`SITE_ID` setting.
+Lino applications don't need ``django.contrib.sites`` 
+(`The "sites" framework
+<https://docs.djangoproject.com/en/dev/ref/contrib/sites/>`_)
+because this 
+functionality is integral part of :mod:`lino.modlib.system`.
+
+
+.. setting:: preview_limit
+    
+Default value for the 
+:attr:`preview_limit <lino.core.tables.AbstractTable.preview_limit>`
+parameter of all tables who don't specify their own one.
+Default value is 15.
+
+
+.. setting:: plain_prefix
+
+The prefix to use for "plain html" URLs.
+Default value is ``'plain'``.
+
+.. setting:: start_year
+
+An integer with the calendar year in which this site starts working.
+Used e.g. 
+by :mod:`lino.modlib.ledger.utils`
+to fill the default list of FixcalYears.
+Or by :mod:`lino.modlib.ledger.fixtures.mini`
+to generate demo invoices.
+
 """
 
+
 from __future__ import unicode_literals
 
 import logging
@@ -41,6 +85,9 @@ from lino.utils import AttrDict
 
 #~ from lino import SETUP_INFO
 
+from django.utils.translation import ugettext_lazy as _
+
+
 from north import Site
 
 import lino
@@ -56,12 +103,9 @@ class Site(Site):
     This is the base for every Lino Site.
     """
     
+    config_id = 1
+    
     preview_limit = 15
-    """
-    Default value for the 
-    :attr:`preview_limit <lino.core.tables.AbstractTable.preview_limit>`
-    parameter of all tables who don't specify their own one.
-    """
     
     
     user_model = None
@@ -787,10 +831,9 @@ class Site(Site):
     Leave this unchanged as long as :doc:`/tickets/70` is not solved.
     """
     
+    start_year = 2011
+    
     plain_prefix = 'plain' 
-    """
-    The prefix to use for the "plain html" URLs.
-    """
     
     #~ admin_prefix = 'admin'
     admin_prefix = '' 
@@ -1256,7 +1299,10 @@ class Site(Site):
     @property
     def site_config(self):
         """
-        Returns the one and only :class:`lino.models.SiteConfig` instance.
+        Returns the one and only 
+        :class:`lino.modlib.system.models.SiteConfig` instance which 
+        contains Site configuration parameters which are stored in the 
+        database and editable using the web interface.
         
         If no instance exists (which happens in a virgin database),
         we create it using default values from :attr:`site_config_defaults`.
@@ -1273,12 +1319,13 @@ class Site(Site):
             #~ from .models import SiteConfig
             #~ from django.db.utils import DatabaseError
             try:
-                self._site_config = SiteConfig.real_objects.get(pk=1)
+                #~ self._site_config = SiteConfig.real_objects.get(pk=1)
+                self._site_config = SiteConfig.real_objects.get(pk=self.config_id)
                 #~ print "20130301 Loaded SiteConfig record", obj2str(self._site_config,True)
             #~ except (SiteConfig.DoesNotExist,DatabaseError):
             except SiteConfig.DoesNotExist:
             #~ except Exception,e:
-                kw = dict(pk=1)
+                kw = dict(pk=self.config_id)
                 #~ kw.update(settings.SITE.site_config_defaults)
                 kw.update(self.site_config_defaults)
                 self._site_config = SiteConfig(**kw)
@@ -1920,7 +1967,7 @@ class Site(Site):
         if today is None: today = datetime.date.today()
         from lino import dd
         if sc and sc.city:
-            return _("%(place)s, %s(date)") % dict(
+            return _("%(place)s, %(date)s") % dict(
                 place=unicode(sc.city.name), date=dd.fdl(today))
         return dd.fdl(today)
         
