@@ -12,7 +12,7 @@ class Site(Site):
         m.add_action(self.modules.lets.Customers)
         m.add_action(self.modules.lets.Providers)
         
-        m = main.add_menu("master","Market")
+        m = main.add_menu("market","Market")
         m.add_action(self.modules.lets.Offers)
         m.add_action(self.modules.lets.Demands)
         
@@ -21,7 +21,8 @@ class Site(Site):
         m.add_action(self.modules.lets.Places)
     
     
-SITE = Site(globals()) 
+#~ SITE = Site(globals(),'lino.modlib.users','lino.tutorials.lets1.lets') 
+SITE = Site(globals(),'lino.tutorials.lets1.lets') 
 
 DEBUG = True
 
@@ -33,15 +34,15 @@ DEBUG = True
     #~ }
 #~ }
 
-INSTALLED_APPS = (
-  'django.contrib.contenttypes',
-  'lino.modlib.users',
-  'lino',
-  'lino.tutorials.lets1.lets'
-)
+#~ INSTALLED_APPS = (
+  #~ 'django.contrib.contenttypes',
+  #~ 'lino.modlib.users',
+  #~ 'lino',
+  #~ 'lino.tutorials.lets1.lets'
+#~ )
 
 #~ LOGGING = dict(level='DEBUG')
 #~ logdir = join(SITE.project_dir,'log')
 #~ if os.path.exists(logdir):
     #~ LOGGING.update(filename=join(logdir,'system.log'))
-    
\ No newline at end of file
+    
