@@ -13,10 +13,15 @@
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
 """
-The Lino process creates a list config_dirs of all 
-configuration directories on server startup
-by looping through :setting:`INSTALLED_APPS` that have a :xfile:`config` 
-subdir.
+This creates a list `config_dirs` of all 
+configuration directories by looping through :setting:`INSTALLED_APPS` 
+and taking those whose source directory has a :xfile:`config` subdir.
+
+..
+
+  DO NOT import this module at the global level of a models module
+  because importing it will fill the config dirs, i.e. will try to import 
+  every installed `models` module.
 
 The mechanism in this module emulates the behaviour of Django's 
 (or Jinja's) template loaders. 
@@ -47,14 +52,18 @@ import logging
 logger = logging.getLogger(__name__)
 
 import os
+from os.path import join, abspath, dirname, normpath, isdir
+
 import sys
 import codecs
+import glob
 
 from fnmatch import fnmatch
 
-from django.conf import settings
 from django.utils.importlib import import_module
+from django.conf import settings
 
+from lino import ad
 from lino.utils import iif
 
 SUBDIR_NAME = 'config' # we might change this to "templates" 
@@ -65,31 +74,41 @@ class ConfigDir:
     
     """
     def __init__(self,name,writeable):
-        self.name = name
+        self.name = os.path.abspath(name)
         self.writeable = writeable
         
     def __repr__(self):
         return "ConfigDir %s" % self.name + iif(self.writeable," (writeable)","")
         
 
-# similar logic as in django.template.loaders.app_directories
 fs_encoding = sys.getfilesystemencoding() or sys.getdefaultencoding()
 config_dirs = []
-for app in settings.INSTALLED_APPS:
-    mod = import_module(app)
-    dirname = os.path.join(os.path.dirname(mod.__file__), SUBDIR_NAME)
-    if os.path.isdir(dirname):
-        config_dirs.append(ConfigDir(dirname.decode(fs_encoding),False))
 
+for pth in settings.SITE.get_settings_subdirs(SUBDIR_NAME):
+    config_dirs.append(ConfigDir(pth.decode(fs_encoding),False))
+
+def add_config_dir(name,mod):
+    pth = join(dirname(mod.__file__),SUBDIR_NAME)    
+    if isdir(pth):
+        config_dirs.append(ConfigDir(pth.decode(fs_encoding),False))
+        
+settings.SITE.for_each_app(add_config_dir)
+
+#~ for app in settings.INSTALLED_APPS:
+    #~ app_mod = import_module(app)
+    #~ app = getattr(app_mod,'App',None)
+    #~ if isinstance(app,ad.App) and app.extends:
+        #~ parent = import_module(app.extends)
+        #~ add_config_dir(parent)
+    #~ add_config_dir(app_mod)
+    
 LOCAL_CONFIG_DIR = None
 
-#~ for dirname in settings.SITE.get_settings_subdirs(SUBDIR_NAME)
-
 #~ if settings.SITE.project_dir != settings.SITE.source_dir:
 if settings.SITE.is_local_project_dir:
-    dirname = os.path.join(settings.SITE.project_dir,SUBDIR_NAME)
-    if os.path.isdir(dirname):
-        LOCAL_CONFIG_DIR = ConfigDir(dirname,True)
+    p = join(settings.SITE.project_dir,SUBDIR_NAME)
+    if isdir(p):
+        LOCAL_CONFIG_DIR = ConfigDir(p,True)
         config_dirs.append(LOCAL_CONFIG_DIR)
 
 config_dirs.reverse()
@@ -101,10 +120,10 @@ config_dirs = tuple(config_dirs)
     #~ app = import_module(app_name)
     #~ fn = getattr(app,'__file__',None)
     #~ if fn is not None:
-        #~ dirname = os.path.join(os.path.dirname(fn),'config')
-        #~ if os.path.isdir(dirname):
-            #~ config_dirs.append(ConfigDir(dirname,False))
-    #~ LOCAL_CONFIG_DIR = ConfigDir(os.path.join(settings.PROJECT_DIR,'config'),True)
+        #~ pth = join(dirname(fn),'config')
+        #~ if isdir(pth):
+            #~ config_dirs.append(ConfigDir(pth,False))
+    #~ LOCAL_CONFIG_DIR = ConfigDir(join(settings.PROJECT_DIR,'config'),True)
     #~ config_dirs.append(LOCAL_CONFIG_DIR)
 
   
@@ -112,11 +131,11 @@ def find_config_file(fn,group=''):
     if os.path.isabs(fn):
         return fn
     if group:
-        prefix = os.path.join(*(group.split('/')))
+        prefix = join(*(group.split('/')))
     else:
         prefix = ''
     for cd in config_dirs:
-        ffn = os.path.join(cd.name,prefix,fn)
+        ffn = join(cd.name,prefix,fn)
         if os.path.exists(ffn):
             return ffn
 
@@ -133,23 +152,23 @@ def find_config_files(pattern,group=''):
     
     """
     if group:
-        prefix = os.path.sep + os.path.join(*(group.split('/')))
+        prefix = os.path.sep + join(*(group.split('/')))
         #~ if not group.endswith('/'):
             #~ group += '/'
     else:
         prefix = ''
     files = {}
     for cd in config_dirs:
-        #~ print 'find_config_files() discover', dirname, pattern
-        dirname = cd.name + prefix
-        if os.path.exists(dirname):
-            for fn in os.listdir(dirname):
+        pth = cd.name + prefix
+        #~ print 'find_config_files() discover', pth, pattern
+        if isdir(pth):
+            for fn in os.listdir(pth):
                 if fnmatch(fn,pattern):
                     files.setdefault(fn,cd)
                     #~ if not files.has_key(fn):
                         #~ files[fn] = cd
         #~ else:
-            #~ print 'find_config_files() not a directory:', dirname
+            #~ print 'find_config_files() not a directory:', pth
     return files
     
 def find_template_config_files(template_ext,templates_group):
@@ -194,8 +213,8 @@ def load_config_files(loader,pattern,group=''):
     files.sort(fcmp)
     prefix = group.replace("/",os.sep)
     for filename,cd in files:
-        filename = os.path.join(prefix,filename)
-        ffn = os.path.join(cd.name,filename)
+        filename = join(prefix,filename)
+        ffn = join(cd.name,filename)
         logger.debug("Loading %s...",ffn)
         s = codecs.open(ffn,encoding='utf-8').read()
         loader(s,cd,filename)
@@ -225,11 +244,11 @@ class Configured(object):
         if not self.cd.writeable:
             #~ print self.cd, "is not writable", self.filename
             self.cd = LOCAL_CONFIG_DIR
-        fn = os.path.join(self.cd.name,self.filename)
-        dirname = os.path.dirname(fn)
-        settings.SITE.makedirs_if_missing(dirname)
-        #~ if not os.path.exists(dirname):
-            #~ os.makedirs(dirname)
+        fn = join(self.cd.name,self.filename)
+        pth = dirname(fn)
+        settings.SITE.makedirs_if_missing(pth)
+        #~ if not os.path.exists(pth):
+            #~ os.makedirs(pth)
         f = codecs.open(fn,'w',encoding='utf-8')
         self.write_content(f)
         f.close()
@@ -244,7 +263,7 @@ class Configured(object):
         """
         if not self.filename: return
         if self.cd is None: return
-        fn = os.path.join(self.cd.name,self.filename)
+        fn = join(self.cd.name,self.filename)
         if self.cd.writeable: 
             logger.info("Not writing %s because %s is writeable",
                 self.filename,self.cd.name)
